@@ -18,10 +18,14 @@ job_status <- function(jobid, token = NULL) {
     headers <- c(headers, "Authorization" = paste("Bearer", token))
   }
 
-  res <- GET(
-    url = paste0("https://pcats.research.cchmc.org/api/job/", jobid, "/status"),
-    add_headers(headers)
-  )
+  tryCatch({
+    res <- GET(
+      url = paste0("https://pcats.research.cchmc.org/api/job/", jobid, "/status"),
+      add_headers(headers)
+    )
+  }, error = function(e) {
+    return(NULL)  # Catch connection errors
+  })
 
   if (res$status_code != 200) {
     return(NULL)
@@ -29,6 +33,5 @@ job_status <- function(jobid, token = NULL) {
 
   status <- jsonlite::fromJSON(httr::content(res, as = "text", encoding = "utf-8"))
 
-  # status<-jsonlite::fromJSON(paste0("https://pcats.research.cchmc.org/api/job/",jobid,"/status"))
-  status
+  unlist(status)
 }
