@@ -13,12 +13,16 @@ uploadfile <- function(filename, token = NULL) {
     headers <- c(headers, "Authorization" = paste("Bearer", token))
   }
 
-  res <- POST(
-    url = paste0("https://pcats.research.cchmc.org/api/uploadfile"),
-    add_headers(headers),
-    encode = "multipart",
-    body = list(data = upload_file(filename))
-  )
+  tryCatch({
+    res <- POST(
+      url = paste0("https://pcats.research.cchmc.org/api/uploadfile"),
+      add_headers(headers),
+      encode = "multipart",
+      body = list(data = upload_file(filename))
+    )
+  }, error = function(e) {
+    return(NULL)  # Catch connection errors
+  })
   cont <- content(res)
   jobid <- cont$jobid[[1]]
   jobid
